﻿using System.Linq;
using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace ThinkGeoProjection
{
    /// <summary>
    ///     Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private RectangleShape _extent;

        public MainWindow()
        {
            InitializeComponent();
            
            mapControl.Loaded += mapControl_Loaded;
        }

        void mapControl_Loaded(object sender, RoutedEventArgs e)
        {
            mapControl.MapUnit = GeographyUnit.Meter;
            var layer = new ShapeFileFeatureLayer(@"source\Cardiff_Boundary_region.shp");
            layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Antarctica1;
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            var staticOverlay = new LayerOverlay
            {
                TransitionEffect = TransitionEffect.None,
                TileType = TileType.SingleTile
            };
            staticOverlay.Layers.Add("layer", layer);
            mapControl.Overlays.Add(staticOverlay);
            layer.Open();
            _extent = layer.GetBoundingBox();
            layer.Close();
            mapControl.CurrentExtent = _extent;
            mapControl.Refresh();
        }


        private void ShowBackground(object sender, RoutedEventArgs e)
        {
            _savedExtent = mapControl.CurrentExtent;
            var managedProj4 = new Proj4Projection
            {
                InternalProjectionParametersString = ManagedProj4Projection.GetEpsgParametersString(27700),
                ExternalProjectionParametersString = ManagedProj4Projection.GetBingMapParametersString()
            };
            managedProj4.Open();
            foreach (var overlay2 in mapControl.Overlays)
            {
                var overlay = (LayerOverlay)overlay2;
                var featureLayer = (FeatureLayer)overlay.Layers.FirstOrDefault();
                if (featureLayer == null)
                    continue;
                featureLayer.FeatureSource.Projection = managedProj4;
            }
            AddBackground();

            RectangleShape externalProjection =
                managedProj4.ConvertToExternalProjection(mapControl.CurrentExtent);
           mapControl.Overlays.ToList().ForEach(x=> mapControl.Refresh(x));

            mapControl.CurrentExtent = externalProjection;
            mapControl.Refresh();
        }

        private RectangleShape _savedExtent=new RectangleShape();
        private void AddBackground()
        {
            var bingMapsOverlay = new BingMapsOverlay("Au9yN0FUHyp5zAoh0zWBjbw81-eSeaiH2J_zTFiCWQ0OYlhYX9i17jR9cnBhQFLJ")
            {
                MapType = BingMapsMapType.Road
            };
           mapControl. Overlays.Insert(0, "Bingmapsoverlay", bingMapsOverlay);
        }

        private void HideBackground(object sender, RoutedEventArgs e)
        {
            var managedProj4 = new Proj4Projection
            {
                InternalProjectionParametersString = ManagedProj4Projection.GetBingMapParametersString(),
                ExternalProjectionParametersString = ManagedProj4Projection.GetEpsgParametersString(27700)
            };
            managedProj4.Open();
            mapControl.Overlays.Remove("Bingmapsoverlay");

            foreach (var overlay2 in mapControl.Overlays)
            {
                var overlay = (LayerOverlay)overlay2;
                var featureLayer = (FeatureLayer)overlay.Layers.FirstOrDefault();
                if (featureLayer == null)
                    continue;

                featureLayer.FeatureSource.Projection = null;
            }

            RectangleShape ex = managedProj4.ConvertToExternalProjection(mapControl.CurrentExtent);
            
            mapControl.CurrentExtent = ex;
            mapControl.Refresh();

        }
    }
}